%%%%%%%%%%%%%%%%%%%%%%%%
% Baronas et al. 2019, Frontiers in Earth Sciences, A first look at
% dissolved Ge isotopes in marine sediments
%
% Core incubation model (Section 5.2.2 in text)
%
% Written and tested on MATLAB 2018b (9.5.0)
% by J.J. Baronas
%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%

%%% internal model ver. 4.3b %%%

%% prep
clear %clear variables

%load core incubation data
load('CI_input.mat')

n = 1000000; %number of MC runs
%% universal parameters
A = 70/10000; %core surface area in m2

%uniform inputs [min; max]
range_D74_feox = [-4.6; -1.6]; % ; Pokrovsky et al. (2014)
range_D74_auth = [-0.3; 0.3];  %; see text

%normal inputs [mu; sigma]
range_d74_lith = [0.58; 0.105]; %; Rouxel & Luais (2017)
range_GeSi_sw = [0.7; 0.05]; %mol/mol; see text
range_d74_sw = [3.28; 0.26]; %; average and 1SD of 0-500m SPB WC values
range_d74_ini = [3.06; 0.17]; %; avg and 1SD of pre-CI bottom OLW
range_FGe_lith = [0.7; 0.13]; %nmol/m2/d; calculated from Leslie et al. (1990), see text
range_d74_pw = [2.13; 0.25]; %; avg and 1SD of all PW below 5cm depth (SPB and SMB)

%make pdfs
pdf_GeSi_sw = makedist('Normal','mu',range_GeSi_sw(1),'sigma',range_GeSi_sw(2));
pdf_d74_sw = makedist('Normal','mu',range_d74_sw(1),'sigma',range_d74_sw(2));
pdf_FGe_lith = makedist('Normal','mu',range_FGe_lith(1),'sigma',range_FGe_lith(2));
pdf_d74_pw = makedist('Normal','mu',range_d74_pw(1),'sigma',range_d74_pw(2));
pdf_d74_ini = makedist('Normal','mu',range_d74_ini(1),'sigma',range_d74_ini(2));
pdf_D74_feox = makedist('Uniform','lower',range_D74_feox(1),'upper',range_D74_feox(2));
pdf_D74_auth = makedist('Uniform','lower',range_D74_auth(1),'upper',range_D74_auth(2));
pdf_d74_lith = makedist('Normal','mu',range_d74_lith(1),'sigma',range_d74_lith(2));

%random sampling
GeSi_sw  = random(pdf_GeSi_sw,n,1); %mol/mol
d74_sw  = random(pdf_d74_sw,n,1); %
d74_ini  = random(pdf_d74_ini,n,1); %
d74_lith  = random(pdf_d74_lith,n,1); %
d74_pw  = random(pdf_d74_pw,n,1); %
D74_feox  = random(pdf_D74_feox,n,1); %
D74_auth  = random(pdf_D74_auth,n,1); %
FGe_lith = random(pdf_FGe_lith,n,1); %nmol/m2/d;

GeSi_bsi = GeSi_sw; %mol/mol; assume no bio fract (based on sed. trap leaches; Baronas et al. (2016) Supp Material)
d74_bsi = d74_sw; %; assume no bio fract; Mantoura (2006); Rouxel & Luais (2017)

 d74_auth = d74_pw + D74_auth; %%; Eq. 11 in text


%% create tables for writing results
out = table; %output
medians = table;
pct_25 = table;
pct_75 = table;

%% calculate for each core

for core = 1:8 %cycle through cores (5 SPB, then 3 SMB, where ?74Ge data available)

    %random sampling of measured values w/in uncertainty 
    pdf_d74_final = makedist('Normal','mu',inp.d74_final(core),'sigma',inp.d74SD(core)); %; measured post-incubation OLW ?74Ge
    d74_final = random(pdf_d74_final,n,1);

    pdf_Ge_ini = makedist('Normal','mu',inp.Ge_ini(core) ,'sigma',inp.Ge_ini(core)*0.025 ); %pmol/L; measured OLW [Ge] prior to incubation   
    Ge_ini = random(pdf_Ge_ini,n,1);

    pdf_h_ini = makedist('Normal','mu',inp.h_ini(core) ,'sigma',0.01); %m; measured OLW column height prior to incubation   
    h_ini = random(pdf_h_ini,n,1);

    pdf_FGe = makedist('Normal','mu',inp.FGe(core),'sigma',inp.FGe(core)*0.1); %nmol/m2/d; measured Ge benthic flux (Table 3)   
    FGe_benthic = random(pdf_FGe,n,1);

    pdf_FSi = makedist('Normal','mu',inp.FSi(core),'sigma',inp.FSi(core)*0.1); %mmol/m2/d; measured Si benthic flux (Table 3)    
    FSi_benthic = random(pdf_FSi,n,1);

    %% CALCULATIONS 

    %measured
    nGe_ini = Ge_ini .* h_ini * A *1000; %nmol; inital Ge inventory in OLW; Eq. 2 in text
    nGe_net = FGe_benthic .* inp.t_fin(core) ./ 24 * A *1000; %nmol; net Ge added in pmols as measured; Eq. 3in text      
    nGe_final = nGe_ini + nGe_net; %nmol; final amt of Ge in post-incubation OLW; Eq. 1 in text
    d74_inc = (d74_final .* nGe_final - d74_ini .* nGe_ini ) ./ nGe_net ; %; Eq. 4 in text
    FGe_bsi = FSi_benthic .* GeSi_bsi; %nmol/m2/d; Ge that is added from bSi dissolution; Eq. 5 in text
   
    %calc dissolving d74 composition
    FGe_supply = FGe_bsi + FGe_lith; %nmol/m2/d; Eq. 6 in text
    d74_supply = ( FGe_bsi .* d74_bsi + FGe_lith .* d74_lith ) ./ FGe_supply; %; composition of dissolving allochtonous seds prior to authigenesis; Eq. 7 in text
     
    %define Feox composition
    d74_feox = d74_supply + D74_feox; %; Eq. 10 in text
    
    %calculate FeOx and auth fluxes from isotope mass balance
    FGe_auth = ( FGe_benthic .* (d74_inc + d74_feox) - FGe_supply .* ( d74_supply + d74_feox) ) ./ (d74_auth - d74_feox); %nmol/m2/d; Eq. 9 in text, rearranged
    FGe_feox = FGe_benthic - FGe_supply - FGe_auth; %nmol/m2/d; Eq. 8 in text, rearranged
  
    %calc fractions relative to allogenic supply (Eq. 12-16 in text)
    f_bsi = FGe_bsi ./ FGe_supply;
    f_lith = FGe_lith ./ FGe_supply;
    f_released = FGe_benthic ./ FGe_supply;
    f_auth = FGe_auth ./ FGe_supply;
    f_feox = FGe_feox ./ FGe_supply;

    %collect outputs in one table
    out.f_bsi = f_bsi;
    out.f_lith = f_lith;
    out.f_feox = f_feox;
    out.f_auth = f_auth;
    out.f_released = f_released;
    out.nGe_ini = nGe_ini;
    out.nGe_net = nGe_net;
    out.FGe_bsi = FGe_bsi;
    out.FGe_supply = FGe_supply;
    out.FGe_feox = FGe_feox;
    out.FGe_lith = FGe_lith;
    out.FGe_auth = FGe_auth;
    out.FGe_flux = FGe_benthic;
    out.d74_net = d74_inc;
    out.d74_supply = d74_supply;
    out.d74_pw = d74_pw;
    out.d74_auth = d74_auth;
    out.d74_bsi = d74_bsi;
    out.d74_lith = d74_lith;
    out.d74_feox = d74_feox;
    out.D74_auth = D74_auth;
    out.D74_feox = D74_feox;
    out.GeSi_sw = GeSi_sw;
    

    %filter out values outside of 2SD analytical and ~reasonable ranges
    %(see Section 5.2.2.1)
    
    out_filt = out( FGe_supply > 0 & FGe_bsi > 0 & FGe_lith > 0 & FGe_auth < 0 ,:); % & f_auth > -10 & f_feox < 10  
   
    %save results in new tables
    for j = 1:width(out)
        medians(core,j) = {median(out_filt{:,j})};
        pct_25(core,j) = {prctile(out_filt{:,j},25)};
        pct_75(core,j) = {prctile(out_filt{:,j},75)};
        out_trimmed =  out_filt( out_filt{:,j}>pct_25{core,j} & out_filt{:,j}<pct_75{core,j},:); %trim values outside of 25-75 percentiles for plotting
    end

    %label columns in new tables
    medians.Properties.VariableNames = out_filt.Properties.VariableNames;
    pct_25.Properties.VariableNames = out_filt.Properties.VariableNames;
    pct_75.Properties.VariableNames = out_filt.Properties.VariableNames;
    out_trimmed.Properties.VariableNames = out_filt.Properties.VariableNames;

    %export filtered results
    Results(core,1) = {inp.Core(core)};
    Results(core,2) = {out_filt};
    Results(core,3) = {height(out_filt)};
    Results(core,4) = {out_trimmed};


end

%% collect results from all cores

%preassign pooled vectors
f_lith_all = [];
f_bsi_all = [];
f_auth_all = [];
f_feox_all = [];
f_released_all = [];
d74_lith_all = [];
d74_bsi_all = [];
d74_supply_all = [];
d74_auth_all = [];
d74_feox_all = [];
d74_flux_all = [];
d74_supply_all2 = [];

%pool data,same no. of points from each core (determined by the core with
% the fewest number of retained MC runs)
plot_density = min([Results{:,3}])-1;

for core = 1:8 %cycle through cores
   
   f_lith_all = [f_lith_all ; Results{core,2}.f_lith(1:plot_density)];
   f_bsi_all = [f_bsi_all ; Results{core,2}.f_bsi(1:plot_density)];
   f_auth_all = [f_auth_all ; Results{core,2}.f_auth(1:plot_density)];
   f_feox_all = [f_feox_all ; Results{core,2}.f_feox(1:plot_density)];
   f_released_all = [f_released_all ; Results{core,2}.f_released(1:plot_density)];
    
   d74_lith_all = [d74_lith_all ; Results{core,2}.d74_lith(1:plot_density)];
   d74_bsi_all = [d74_bsi_all ; Results{core,2}.d74_bsi(1:plot_density)];
   d74_supply_all = [d74_supply_all ; Results{core,2}.d74_supply(1:plot_density)];  
   d74_auth_all = [d74_auth_all ; Results{core,2}.d74_auth(1:plot_density)];
   d74_feox_all = [d74_feox_all ; Results{core,2}.d74_feox(1:plot_density)];
   
   if core ~= 4 %skip 5A, as it has highly uncertain values, skewing the combined stats
    d74_flux_all = [d74_flux_all ; Results{core,2}.d74_net(1:plot_density)];
    d74_supply_all2 = [d74_supply_all2 ; Results{core,2}.d74_supply(1:plot_density)];
   end

end

%% collect the summary of combined results in a new table
medians_comb = table;

%medians
medians_comb.f_lith_all = median(f_lith_all);
medians_comb.f_bsi_all =median(f_bsi_all);
medians_comb.f_auth_all =median(f_auth_all);
medians_comb.f_feox_all = median(f_feox_all);
medians_comb.f_released_all = median(f_released_all);
medians_comb.d74_supply_all =median(d74_supply_all);
medians_comb.d74_auth_all = median(d74_auth_all);
medians_comb.d74_feox_all = median(d74_feox_all);
medians_comb.d74_flux_all =median(d74_flux_all);

%2SD
medians_comb.f_lith_all(2) = 2*std(f_lith_all);
medians_comb.f_bsi_all(2) =2*std(f_bsi_all);
medians_comb.f_auth_all(2) =2*std(f_auth_all);
medians_comb.f_feox_all(2) = 2*std(f_feox_all);
medians_comb.f_released_all(2) = 2*std(f_released_all);
medians_comb.d74_supply_all(2) =2*std(d74_supply_all);
medians_comb.d74_auth_all(2) = 2*std(d74_auth_all);
medians_comb.d74_feox_all(2) = 2*std(d74_feox_all);
medians_comb.d74_flux_all(2) =2*std(d74_flux_all);

%25th percentile
medians_comb.f_lith_all(3) = prctile(f_lith_all,25);
medians_comb.f_bsi_all(3) =prctile(f_bsi_all,25);
medians_comb.f_auth_all(3) =prctile(f_auth_all,25);
medians_comb.f_feox_all(3) = prctile(f_feox_all,25);
medians_comb.f_released_all(3) = prctile(f_released_all,25);
medians_comb.d74_supply_all(3) =prctile(d74_supply_all,25);
medians_comb.d74_auth_all(3) = prctile(d74_auth_all,25);
medians_comb.d74_feox_all(3) = prctile(d74_feox_all,25);
medians_comb.d74_flux_all(3) =prctile(d74_flux_all,25);

%75th percentile
medians_comb.f_lith_all(4) = prctile(f_lith_all,75);
medians_comb.f_bsi_all(4) =prctile(f_bsi_all,75);
medians_comb.f_auth_all(4) =prctile(f_auth_all,75);
medians_comb.f_feox_all(4) = prctile(f_feox_all,75);
medians_comb.f_released_all(4) = prctile(f_released_all,75);
medians_comb.d74_supply_all(4) =prctile(d74_supply_all,75);
medians_comb.d74_auth_all(4) = prctile(d74_auth_all,75);
medians_comb.d74_feox_all(4) = prctile(d74_feox_all,75);
medians_comb.d74_flux_all(4) =prctile(d74_flux_all,75);


    