%%%%%%%%%%%%%%%%%%%%%%%%
% Baronas et al. 2019, Frontiers in Earth Sciences, A first look at
% dissolved Ge isotopes in marine sediments
%
% Global shelf Ge (isotope) budget (Section 5.3 in text)
%
% Written and tested on MATLAB 2018b (9.5.0)
% by J.J. Baronas
%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%


%% prep
clear %clear variables
n = 1000000; %no of MC runs


%% inputs
%normal pdf: mu; sigma
range_Ge_UCC = [1.4; 0.1]; %ppm; Rudnick & Gao (2014)
range_Fe_UCC = [0.0504; 0.0053]; % g/g; Rudnick & Gao (2014)
range_FGe_riv_diss = [3.2; 0.6]; %Mmol/y; Baronas et al. (2017)
range_J_SPB_detrital = [0.35; 0.015]; %g/m2/d; Collins et al. (2011)
range_d74_lith = [0.58; 0.105]; %Rouxel & Luais (2017)
range_d74_bsi = [2.5; 3.5]; % Guillermic et al. (2017)

%uniform pdf: min; max
range_GeSi_bSi = [0.5; 0.7];
range_fGe_diss = [0.01; 0.1]; %Baronas et al. (2018)
range_FSi_shelf_bSi = [16-3.3; 87-3.3]; %Tmol/y; Treguer & De La Rocha (2013); 3.3 Tmol/y buried

%uncertainty unknown
J_SPB_FeOx = 26 ; %nmol/m2/d; Leslie et al. (1990) 
J_shelf_lith = 19100; %global river sediment flux in Mt/y; Milliman & Farnsworth (2011)

%% make pdfs
pdf_Ge_UCC = makedist('Normal','mu',range_Ge_UCC(1),'sigma',range_Ge_UCC(2));
pdf_Fe_UCC = makedist('Normal','mu',range_Fe_UCC(1),'sigma',range_Fe_UCC(2));
pdf_FGe_riv_diss = makedist('Normal','mu',range_FGe_riv_diss(1),'sigma',range_FGe_riv_diss(2));
pdf_J_SPB_detrital = makedist('Normal','mu',range_J_SPB_detrital(1),'sigma',range_J_SPB_detrital(2));
pdf_d74_lith = makedist('Normal','mu',range_d74_lith(1),'sigma',range_d74_lith(2));

pdf_GeSi_bSi = makedist('Uniform','lower',range_GeSi_bSi(1),'upper',range_GeSi_bSi(2));
pdf_fGe_diss = makedist('Uniform','lower',range_fGe_diss(1),'upper',range_fGe_diss(2));
pdf_FSi_shelf_bSi = makedist('Uniform','lower',range_FSi_shelf_bSi(1),'upper',range_FSi_shelf_bSi(2));
pdf_d74_bsi = makedist('Uniform','lower',range_d74_bsi(1),'upper',range_d74_bsi(2));


%% random sampling

Ge_UCC  = random(pdf_Ge_UCC,n,1);
Fe_UCC  = random(pdf_Fe_UCC,n,1);
GeSi_bSi  = random(pdf_GeSi_bSi,n,1);
FGe_riv_diss = random(pdf_FGe_riv_diss,n,1);
J_SPB_detrital = random(pdf_J_SPB_detrital,n,1);
fGe_diss = random(pdf_fGe_diss,n,1);
FSi_shelf_bSi = random(pdf_FSi_shelf_bSi,n,1);
d74_bSi  = random(pdf_d74_bsi,n,1);
d74_lith  = random(pdf_d74_lith,n,1);


%% calculations

GeFe_UCC = Ge_UCC ./ Fe_UCC .* (55.845+16) ./ 72.6; %mol/mol
FGe_SPB_lithtotal = J_SPB_detrital .* Ge_UCC ./ 72.6 .*1000; %nmol/m2/d --Eq 17 in text
FGe_SPB_lithdiss = GeFe_UCC .* J_SPB_FeOx ./ 1000; %nmol/m2/d --Eq 18 in text
fGe_lith_released = FGe_SPB_lithdiss ./ FGe_SPB_lithtotal;  %no units --Eq 19 in text
FGe_shelf_bSi = FSi_shelf_bSi .* GeSi_bSi; %Mmol/y  --Eq 20 in text
FGe_shelf_lithtotal_ALT = J_shelf_lith .* Ge_UCC ./ 72.6 ; %Mmol/y 
FGe_shelf_lithtotal = FGe_riv_diss ./ fGe_diss - FGe_riv_diss; %Mmol/y --Eq 21 in text
FGe_shelf_lithdiss =  fGe_lith_released .* FGe_shelf_lithtotal; %Mmol/y --Eq 22 in text

f_in_lith  = FGe_shelf_lithdiss ./ (FGe_shelf_lithdiss + FGe_shelf_bSi); %fraction lithogenic in allochthonous supply

% --Eq 23 in text
d74Ge_globalshelf_in = 	(FGe_shelf_bSi .* d74_bSi + FGe_shelf_lithdiss .* d74_lith) ./ (FGe_shelf_bSi + FGe_shelf_lithdiss); 

%% show results
 histogram(d74Ge_globalshelf_in) %plot results
 xlabel('\delta^{74}Ge_{shelf-input} ()')
 
 median(d74Ge_globalshelf_in) %print median value
 std(d74Ge_globalshelf_in) %print 1 sigma
 
 
%% f_out_auth -- test a range of values based on previous porewater and core inc results (Baronas 2016 GCA)
	
range_f_out_auth = [0.1; 0.6]; %fraction of dissolved Ge sequestered into authigenic phases
pdf_f_out_auth = makedist('Uniform','lower',range_f_out_auth(1),'upper',range_f_out_auth(2));
f_out_auth  = random(pdf_f_out_auth,n,1);

Fburial_auth_lith = f_out_auth .* FGe_shelf_lithdiss ; %Mmol/y -- authigenic burial flux of lithogenic-derived Ge
Fburial_auth_bSi = f_out_auth .* FGe_shelf_bSi ; %Mmol/y -- authigenic burial flux of biogenic-derived Ge
Fburial_auth_total = Fburial_auth_lith + Fburial_auth_bSi ; %Mmol/y -- total authigenic burial flux of Ge

Fbenth_lith = FGe_shelf_lithdiss - Fburial_auth_lith ; %Mmol/y -- benthic flux of lithogenic-derived Ge
Fbenth_bSi = FGe_shelf_bSi - Fburial_auth_bSi ; %Mmol/y -- benthic flux of biogenic-derived Ge


%% tabulate all results

RESULTS = table;

%median
RESULTS.FGe_bSi_shelf(1) = median(FGe_shelf_bSi) ;
RESULTS.FGe_shelf_lithtotal(1) = median(FGe_shelf_lithtotal) ; 
RESULTS.FGe_SPB_lithtotal(1) = median(FGe_SPB_lithtotal) ;
RESULTS.fGe_lith_released(1) = median(fGe_lith_released) ; 
RESULTS.FdGe_lith_globalshelf(1) = median(FGe_shelf_lithdiss) ;
RESULTS.d74Ge_globalshelf_in(1) = median(d74Ge_globalshelf_in) ;
RESULTS.f_in_lith(1) = median(f_in_lith);

RESULTS.Fburial_auth_lith(1) = median(Fburial_auth_lith) ; 
RESULTS.Fburial_auth_bSi(1) = median(Fburial_auth_bSi) ; 
RESULTS.Fburial_auth_total(1) = median(Fburial_auth_total) ; 
RESULTS.Fbenth_lith(1) = median(Fbenth_lith) ; 
RESULTS.Fbenth_bSi(1) = median(Fbenth_bSi) ; 

%stdev
RESULTS.FGe_bSi_shelf(2) = std(FGe_shelf_bSi) ;
RESULTS.FGe_shelf_lithtotal(2) = std(FGe_shelf_lithtotal) ; 
RESULTS.FGe_SPB_lithtotal(2) = std(FGe_SPB_lithtotal) ;
RESULTS.fGe_lith_released(2) = std(fGe_lith_released) ; 
RESULTS.FdGe_lith_globalshelf(2) = std(FGe_shelf_lithdiss) ;
RESULTS.d74Ge_globalshelf_in(2) = std(d74Ge_globalshelf_in) ;
RESULTS.f_in_lith(2) = std(f_in_lith);

RESULTS.Fburial_auth_lith(2) = std(Fburial_auth_lith) ; 
RESULTS.Fburial_auth_bSi(2) = std(Fburial_auth_bSi) ; 
RESULTS.Fburial_auth_total(2) = std(Fburial_auth_total) ; 
RESULTS.Fbenth_lith(2) = std(Fbenth_lith) ; 
RESULTS.Fbenth_bSi(2) = std(Fbenth_bSi) ; 

%25th percentile
RESULTS.FGe_bSi_shelf(3) = prctile(FGe_shelf_bSi,25) ;
RESULTS.FGe_shelf_lithtotal(3) = prctile(FGe_shelf_lithtotal,25) ; 
RESULTS.FGe_SPB_lithtotal(3) = prctile(FGe_SPB_lithtotal,25) ;
RESULTS.fGe_lith_released(3) = prctile(fGe_lith_released,25) ; 
RESULTS.FdGe_lith_globalshelf(3) = prctile(FGe_shelf_lithdiss,25) ;
RESULTS.d74Ge_globalshelf_in(3) = prctile(d74Ge_globalshelf_in,25) ;
RESULTS.f_in_lith(3) = prctile(f_in_lith,25) ;

RESULTS.Fburial_auth_lith(3) = prctile(Fburial_auth_lith,25) ; 
RESULTS.Fburial_auth_bSi(3) = prctile(Fburial_auth_bSi,25) ; 
RESULTS.Fburial_auth_total(3) = prctile(Fburial_auth_total,25) ; 
RESULTS.Fbenth_lith(3) = prctile(Fbenth_lith,25) ; 
RESULTS.Fbenth_bSi(3) = prctile(Fbenth_bSi,25) ; 

%75th percentile
RESULTS.FGe_bSi_shelf(4) = prctile(FGe_shelf_bSi,75) ;
RESULTS.FGe_shelf_lithtotal(4) = prctile(FGe_shelf_lithtotal,75) ; 
RESULTS.FGe_SPB_lithtotal(4) = prctile(FGe_SPB_lithtotal,75) ;
RESULTS.fGe_lith_released(4) = prctile(fGe_lith_released,75) ; 
RESULTS.FdGe_lith_globalshelf(4) = prctile(FGe_shelf_lithdiss,75) ;
RESULTS.d74Ge_globalshelf_in(4) = prctile(d74Ge_globalshelf_in,75) ;
RESULTS.f_in_lith(4) = prctile(f_in_lith, 75);

RESULTS.Fburial_auth_lith(4) = prctile(Fburial_auth_lith,75) ; 
RESULTS.Fburial_auth_bSi(4) = prctile(Fburial_auth_bSi,75) ; 
RESULTS.Fburial_auth_total(4) = prctile(Fburial_auth_total,75) ; 
RESULTS.Fbenth_lith(4) = prctile(Fbenth_lith,75) ; 
RESULTS.Fbenth_bSi(4) = prctile(Fbenth_bSi,75) ; 

RESULTS.Properties.RowNames = {'median'; 'stdev'; '25th prctl'; '75th prctl'};